/*
 * Copyright (C) by Klaas Freitag <freitag@edudrive.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 * for more details.
 */

#ifndef EDUDRIVE_THEME_H
#define EDUDRIVE_THEME_H

#include "theme.h"

#include <QString>
#include <QVariant>
#ifndef TOKEN_AUTH_ONLY
#include <QPixmap>
#include <QIcon>
#include <QStyle>
#include <QApplication>
#endif
#include <QCoreApplication>


#include "config.h"
#include "common/utility.h"
#include "version.h"


namespace OCC {
  /**
   * @brief The edudriveTheme class
   * @ingroup libsync
   */
  class edudriveTheme : public Theme
  {
    public:

      edudriveTheme() : Theme() {}

      QString configFileName() const
      {
        return QLatin1String("edudrive.cfg");
      }

      QString enforcedLocale() const {
        return QLatin1String("pt_BR");
      }

      bool wizardSelectiveSyncDefaultNothing() const{
        return true;
      }

#ifndef TOKEN_AUTH_ONLY
      QColor wizardHeaderBackgroundColor() const
      {
        return QColor("#428ac9");
      }

      QColor wizardHeaderTitleColor() const
      {
        return QColor("#ffffff");
      }

      QPixmap wizardHeaderLogo() const
      {
        return QPixmap(hidpiFileName(":/client/theme/colored/wizard_logo.png"));
      }


      QIcon applicationIcon() const
      {
        return themeIcon(QLatin1String("edudrive-icon"));
      }
#endif

      QString appName() const
      {
        return QLatin1String("edudrive@RNP");
      }

      QString appNameGUI() const
      {
        return QLatin1String("edudrive@RNP");
      }

      QString overrideServerUrl() const
      {
        return QLatin1String("https://edudrive.rnp.br");
      }
      
     bool aboutShowCopyright() const
      {
          return true;
      }
      QString about() const
      {
        QString vendor = APPLICATION_VENDOR;
        // Ideally, the vendor should be "ownCloud GmbH", but it cannot be changed without
        // changing the location of the settings and other registery keys.
        QString devString;
        devString = tr("<p>Version %2. For more information visit <a href=\"%3\">https://%4</a></p>"
                          "<p>For known issues and help, please send email to: <strong>sd@rnp.br</strong></p>"
                          "<p><small>By Klaas Freitag, Daniel Molkentin, Olivier Goffart, Markus Götz, "
                          " Jan-Christoph Borchardt, and others.</small></p>")
                        .arg(Utility::escape(MIRALL_VERSION_STRING),
                            Utility::escape("https://" MIRALL_STRINGIFY(APPLICATION_DOMAIN)),
                            Utility::escape(MIRALL_STRINGIFY(APPLICATION_DOMAIN)));
        devString += tr("<p>Copyright ") + vendor + "</p>";
        devString += tr("<p>Distributed by %1 and licensed under the GNU General Public License (GPL) Version 2.0.<br/>"
                        "%2 and the %2 logo are registered trademarks of %1 in the "
                        "Brazil, other countries, or both.</p>")
                  .arg(Utility::escape(vendor), Utility::escape(APPLICATION_NAME));
        devString += gitSHA1();
        devString += QString("<p><small>Using virtual files plugin: %1</small></p>")
            .arg(Vfs::modeToString(bestAvailableVfsMode()));
        return devString;
     }
  };
}
#endif // EDUDRIVE_MIRALL_THEME_H
